===========
Descriptive
===========

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    Series.chunk_lengths
    Series.describe
    Series.estimated_size
    Series.has_nulls
    Series.has_validity
    Series.is_duplicated
    Series.is_empty
    Series.is_finite
    Series.is_first_distinct
    Series.is_in
    Series.is_infinite
    Series.is_last_distinct
    Series.is_nan
    Series.is_not_nan
    Series.is_not_null
    Series.is_null
    Series.is_sorted
    Series.is_unique
    Series.len
    Series.lower_bound
    Series.n_chunks
    Series.n_unique
    Series.null_count
    Series.unique_counts
    Series.upper_bound
    Series.value_counts
